=============
Running tests
=============

The tests are run using tox_. See its documentation for details.

.. _tox : https://pypi.python.org/pypi/tox

==============================
Developing gocept.pseudonymize
==============================

:Author:
    `gocept <http://gocept.com/>`_ <mail@gocept.com>

:Online documentation:
    http://pythonhosted.org/gocept.pseudonymize/

:PyPI page:
    http://pypi.python.org/pypi/gocept.pseudonymize/

:Issues:
    https://bitbucket.org/gocept/gocept.pseudonymize/issues

:Source code:
    https://bitbucket.org/gocept/gocept.pseudonymize/

:Current change log:
    https://bitbucket.org/gocept/gocept.pseudonymize/raw/tip/CHANGES.txt
